@@ -35,7 +35,7 @@ class OAuthState(object):
         try:
             self.token = self.token.get_access_token()
         except urllib2.HTTPError, exc:
-            if exc.getcode() == 401:
+            if exc.code == 401:
                 raise self.AccessDenied(exc.filename, exc.code, exc.msg,
                                         exc.hdrs, exc.fp)
             raise
@@ -106,4 +106,4 @@ class OAuthState(object):
         return self.session_key_prefix + '_state'
 
 
-OAuthState.contribute_to_class(Consumer)
\ No newline at end of file
+OAuthState.contribute_to_class(Consumer)
